@@ -54,8 +54,8 @@ function(input, output, session) {
   })
 
   formatstats  <- reactive({
-    df <- maindata()
-    shiny::req(df)
+    shiny::req(maindata())
+    
     validate(need(
       length(input$covariates) >= 1,
       "Please select a least one covariate or All"
@@ -64,6 +64,7 @@ function(input, output, session) {
       length(input$covvalueorder) >= 1,
       "Please select a least one covariate/All level"
     ))
+    df <- maindata()
     df$covname <- factor(df$covname)
     df$label <- factor(df$label)
     df$exposurename <- df$paramname
@@ -74,9 +75,9 @@ function(input, output, session) {
         MEANEXP = mid,
         LOWCI = lower,
         UPCI =  upper,
-        MEANLABEL = round_pad(MEANEXP, sigdigits),
-        LOWCILABEL = round_pad(LOWCI, sigdigits),
-        UPCILABEL = round_pad(UPCI, sigdigits),
+        MEANLABEL = signif_pad(MEANEXP, sigdigits),
+        LOWCILABEL = signif_pad(LOWCI, sigdigits),
+        UPCILABEL = signif_pad(UPCI, sigdigits),
         LABEL = paste0(MEANLABEL, " [", LOWCILABEL, "-", UPCILABEL, "]")
       )
 
@@ -142,8 +143,7 @@ function(input, output, session) {
   })
 
   output$plot <- renderPlot({
-    summarydata <- plotdataprepare()
-    shiny::req(summarydata)
+    shiny::req(plotdataprepare())
 
     major_x_ticks <- NULL
     minor_x_ticks <- NULL
@@ -155,69 +155,81 @@ function(input, output, session) {
         minor_x_ticks <- as.numeric(unique(unlist(strsplit(input$xaxisminorbreaks, ",")[[1]])))
       }, warning = function(w) {}, error = function(e) {})
     }
+    x_range <- if (input$userxzoom) c(input$lowerxin, input$upperxin) else NULL
+    ref_value <- if (is.na(input$refvalue)) 1 else input$refvalue
 
-    plot <- forest_plot(
-      data = summarydata,
-      facet_formula = input$facetformula,
-      xlabel = input$xaxistitle,
-      ylabel = input$yaxistitle,
-      x_facet_text_size = input$facettextx,
-      y_facet_text_size = input$facettexty,
-      x_facet_text_angle = input$facettextxangle,
-      y_facet_text_angle = input$facettextyangle,
-      xy_facet_text_bold = input$boldfacettext,
-      x_label_text_size = input$xlablesize,
-      y_label_text_size = input$ylablesize,
-      table_text_size = input$tabletextsize,
-      base_size = input$base_size,
-      theme_benrich = input$theme_benrich,
-      table_title = escape_newline(input$custom_table_title),
-      table_title_size = input$table_title_size,
-      ref_legend_text = escape_newline(input$customlinetypetitle),
-      area_legend_text = escape_newline(input$customfilltitle),
-      interval_legend_text = escape_newline(input$customcolourtitle),
-      interval_bsv_text = escape_newline(input$custombsvtitle),
-      legend_order = input$legendordering,
-      combine_area_ref_legend = input$combineareareflegend,
-      legend_position = input$legendposition,
-      show_ref_area = input$showrefarea,
-      ref_area = input$refareain,
-      ref_value = ifelse(is.na(input$refvalue),1,input$refvalue),
-      ref_area_col = input$fillrefarea,
-      ref_value_col = input$colorrefvalue,
-      interval_col = input$colourpointrange,
-      bsv_col      = input$colourbsvrange,
-      strip_col = input$stripbackgroundfill,
-      paramname_shape = input$shapebyparamname,
-      legend_shape_reverse = input$legendshapereverse,
-      facet_switch = input$facetswitch,
-      facet_scales = input$facetscales,
-      facet_space = input$facetspace,
-      strip_placement = input$stripplacement,
-      strip_outline = input$removestrip,
-      facet_spacing = input$panelspacing,
-      major_x_ticks = major_x_ticks,
-      minor_x_ticks = minor_x_ticks,
-      x_range = if (input$userxzoom) c(input$lowerxin, input$upperxin),
-      logxscale = input$logxscale,
-      show_yaxis_gridlines = input$showyaxisgridlines,
-      show_xaxis_gridlines = input$showxaxisgridlines,
-      show_table_facet_strip = input$showtablefacetstrips,
-      table_facet_switch = input$tablefacetswitch,
-      show_table_yaxis_tick_label = input$showtableyaxisticklabel,
-      table_panel_border = input$tablepanelborder,
-      reserve_table_xaxis_label_space = input$reservetablexaxislabelspace,
-      table_position = input$tableposition,
-      plot_table_ratio = input$plottotableratio,
-      vertical_dodge_height = input$vdodgeheight,
-      legend_space_x_mult = input$legendspacex,
-      legend_ncol_interval = input$ncolinterval,
-      legend_ncol_shape = input$ncolshape,
-      plot_margin = c(input$margintop,input$marginright,
-                      input$marginbottom,input$marginleft),
-      table_margin = c(input$tabletop,input$tableright,
-                      input$tablebottom,input$tableleft)
-    )
+summarydata <- plotdataprepare()
+          plot <- forest_plot(
+        data = summarydata,
+        facet_formula = input$facetformula,
+        xlabel = input$xaxistitle,
+        ylabel = input$yaxistitle,
+        x_facet_text_size = input$facettextx,
+        y_facet_text_size = input$facettexty,
+        x_facet_text_angle = input$facettextxangle,
+        y_facet_text_angle = input$facettextyangle,
+        x_facet_text_vjust = input$x_facet_text_vjust,
+        y_facet_text_vjust = input$y_facet_text_vjust,
+        x_facet_text_hjust = input$x_facet_text_hjust,
+        y_facet_text_hjust = input$y_facet_text_hjust,
+        xy_facet_text_bold = input$boldfacettext,
+        x_label_text_size = input$xlablesize,
+        y_label_text_size = input$ylablesize,
+        table_text_size = input$tabletextsize,
+        base_size = input$base_size,
+        theme_benrich = input$theme_benrich,
+        table_title = escape_newline(input$custom_table_title),
+        table_title_size = input$table_title_size,
+        ref_legend_text = escape_newline(input$customlinetypetitle),
+        area_legend_text = escape_newline(input$customfilltitle),
+        interval_legend_text = escape_newline(input$customcolourtitle),
+        interval_bsv_text = escape_newline(input$custombsvtitle),
+        legend_order = input$legendordering,
+        combine_area_ref_legend = input$combineareareflegend,
+        legend_position = input$legendposition,
+        show_ref_area = input$showrefarea,
+        ref_area = input$refareain,
+        show_ref_value = input$showrefvalue,
+        ref_value = ref_value,
+        ref_area_col = input$fillrefarea,
+        ref_value_col = input$colorrefvalue,
+        interval_col = input$colourpointrange,
+        bsv_col      = input$colourbsvrange,
+        strip_col = input$stripbackgroundfill,
+        paramname_shape = input$shapebyparamname,
+        legend_shape_reverse = input$legendshapereverse,
+        facet_switch = input$facetswitch,
+        facet_scales = input$facetscales,
+        facet_space = input$facetspace,
+        strip_placement = input$stripplacement,
+        strip_outline = input$removestrip,
+        facet_spacing = input$panelspacing,
+        major_x_ticks = major_x_ticks,
+        minor_x_ticks = minor_x_ticks,
+        x_range = x_range,
+        logxscale = input$logxscale,
+        show_yaxis_gridlines = input$showyaxisgridlines,
+        show_xaxis_gridlines = input$showxaxisgridlines,
+        show_table_facet_strip = input$showtablefacetstrips,
+        table_facet_switch = input$tablefacetswitch,
+        show_table_yaxis_tick_label = input$showtableyaxisticklabel,
+        table_panel_border = input$tablepanelborder,
+        reserve_table_xaxis_label_space = input$reservetablexaxislabelspace,
+        table_position = input$tableposition,
+        plot_table_ratio = input$plottotableratio,
+        vertical_dodge_height = input$vdodgeheight,
+        legend_space_x_mult = input$legendspacex,
+        legend_ncol_interval = input$ncolinterval,
+        legend_ncol_shape = input$ncolshape,
+        plot_margin = c(input$margintop,input$marginright,
+                        input$marginbottom,input$marginleft),
+        table_margin = c(input$tabletop,input$tableright,
+                        input$tablebottom,input$tableleft),
+        legend_margin = c(input$legendtop,input$legendright,
+                         input$legendbottom,input$legendleft),
+        parse_xlabel = input$parsexaxistitle,
+        parse_ylabel = input$parseyaxistitle
+      )
     plot
   }, height = function() {
     input$height
